#!/usr/bin/perl -w
#------------------------------------------------------------------------------
#Skriptname         : bookmarksync.pl
#Skriptversion      : 0.10
#Last Changed       : 12.10.2003
#Start	            : 12.10.2003
#Autor              : Sascha.Herrmann@web.de
#Description        :
#Dependency         : - bookmarksync-0.3.2
#                         http://sourceforge.net/projects/booksync/
#                     - ssh and scp
#                         http://www.openssh.org
#Changelog  :
# 0.10 / <12.10.03> : Initial version
#------------------------------------------------------------------------------

use strict;
#
# Put in your master and slave location
# but be aware to ALWAYS use the format:
# user@target_name_or_ip:/the/file/location.html
#
my $master_file = "/home/user/.mozilla/user/nwoirvt5.slt/bookmarks.html";
my @locations = (
	'test@localhost:/home/test/.phoenix/default/ght6n2kj.slt/bookmarks.html',
	'me@123.456.78.9:.mozilla/default/7hdgt53.slt/bookmarks.html',
);

# these are vars for workflow control
my $only_dist = 0;
my $debug = ">/dev/null";
my $debug_opt = "";

#Start of the main program
# parse the command line
foreach (@ARGV) {
  if ( $_ eq "-h" or $_ eq "--h" or $_ eq "--help" ) {
    print "Usage: bookmarksync.pl [options]\nAvailable Options:\n";
    print "\t-h, --h, --help\tprint this help\n";
    print "\t-d, --debug\tprint debug messages\n";
    print "\t-od\t\tonly distribute master file to slave files (this will override your slaves!)\n";
    print "\nWithout any option, the script will first fetch the slave files,\nmerge them with the master file, and redistribute them back to their origin.";
    exit 0;
  }
  elsif ( $_ eq "-od" or $_ eq "--only-distribute") {
    $only_dist = 1;
  }
  elsif ( $_ eq "-d" or $_ eq  "--debug" ) {
    $debug = "";
    $debug_opt = "-v";
  }
}
my $date=`date +%d%m%Y`;

# make a backup copy of the master file
system("/bin/cp -f $debug_opt $master_file $master_file.$date $debug");
unless ($only_dist) {
  print "Starting to fetch slave files ...\n";
  foreach (@locations) {
    print "Now processing line: $_\n";
    # first check if the host is avialable
    my @line = split /:/;
    my @host = split /@/, $line[0];
    my $host = $host[1];
    unless ( $host eq "localhost" ) {
      next if ( system("/bin/ping -c 1 $host $debug") != 0 );
      # now copy remote file to local machine
      system("/usr/bin/scp $debug_opt $_ /tmp/slave_bookmark_file.html $debug");
      }
    else { # we are on localhost, so a simple cp does the job
      system("/bin/cp -f $debug_opt $line[1] /tmp/slave_bookmark_file.html $debug");
      }
    # sync master and remote file
    system("/usr/bin/bookmarksync $debug_opt -o $master_file.'new' $master_file /tmp/slave_bookmark_file.html $debug");
    # overwrite old master file
    system("/bin/mv -f $debug_opt $master_file.'new' $master_file $debug");
    }
}

#start redistribution
print "Starting to distribute master file to slave locations...\n";
foreach (@locations) {
  print "Now processing line: $_\n";
  # now redistribute the merged master file
  # first check if the host is avialable
  my @line = split /:/;
  my @host = split /@/, $line[0];
  my $host = $host[1];
  unless ( $host eq "localhost" ) {
    next if ( system("/bin/ping -c 1 $host $debug") != 0 );
    system("/usr/bin/scp $debug_opt $master_file $_ $debug");
  }
  else { # we are on localhost, so a simple cp does the job
    system("/bin/cp -f $debug_opt $master_file $line[1] $debug");
  }
}
system("/bin/rm -f $debug_opt /tmp/slave_bookmark_file.html $debug");
print "Well done!\n";
exit;
